@@ -14,7 +14,7 @@
 
 
 import abc
-import collections
+import copy
 import gzip
 import io
 import time
@@ -30,24 +30,6 @@ from cloudbaseinit.utils import encoding
 CONF = cloudbaseinit_conf.CONF
 LOG = oslo_logging.getLogger(__name__)
 
-# Both the custom service(s) and the networking plugin
-# should know about the entries of these kind of objects.
-NetworkDetails = collections.namedtuple(
-    "NetworkDetails",
-    [
-        "name",
-        "mac",
-        "address",
-        "address6",
-        "netmask",
-        "netmask6",
-        "broadcast",
-        "gateway",
-        "gateway6",
-        "dnsnameservers",
-    ]
-)
-
 
 class NotExistingMetadataException(Exception):
     pass
@@ -129,6 +111,19 @@ class BaseMetadataService(object):
         """Get a list of space-stripped strings as public keys."""
         pass
 
+    def get_user_pwd_encryption_key(self):
+        """Get the user password encryption public key as a string.
+
+        The encryption public key, if existent, will be used to encrypt the
+        user password to be sent to the metadata service.
+        By default, the first public key set by the user
+        will be used to encrypt the user password.
+
+        """
+        public_keys = self.get_public_keys()
+        if public_keys:
+            return list(public_keys)[0]
+
     def get_network_details(self):
         """Return a list of `NetworkDetails` objects.
 
@@ -137,6 +132,9 @@ class BaseMetadataService(object):
         in the namedtuple defined above.
         """
 
+    def get_network_details_v2(self):
+        """Return a `NetworkDetailsV2` object."""
+
     def get_admin_username(self):
         pass
 
@@ -157,6 +155,12 @@ class BaseMetadataService(object):
     def get_winrm_listeners_configuration(self):
         pass
 
+    def get_server_certs(self):
+        pass
+
+    def get_vm_agent_package_provisioning_data(self):
+        pass
+
     def get_client_auth_certs(self):
         pass
 
@@ -189,6 +193,15 @@ class BaseMetadataService(object):
         """
         return False
 
+    def provisioning_started(self):
+        pass
+
+    def provisioning_completed(self):
+        pass
+
+    def provisioning_failed(self):
+        pass
+
     @property
     def can_post_rdp_cert_thumbprint(self):
         return False
@@ -206,10 +219,52 @@ class BaseMetadataService(object):
         """Check if the metadata provider enforces automatic updates."""
         pass
 
+    def get_ephemeral_disk_data_loss_warning(self):
+        raise NotExistingMetadataException()
+
+    def get_instance_data(self):
+        """Returns a dictionary with instance data from the metadata source
+
+        The instance data structure is based on the cloud-init specifications:
+        https://cloudinit.readthedocs.io/en/latest/topics/instancedata.html
+
+        The v1 namespace contains a subset of the cloud-init standard
+        for the instance data. In the future, it should reach parity with the
+        cloud-init standard.
+
+        The ds.meta_data namespace contains all the values the v1 namespace
+        contains, in order to be compatible with cloud-init, plus a subset of
+        other instance data.
+        The ds namespace can change without prior notice and should not be
+        used in production.
+        """
+
+        instance_id = self.get_instance_id()
+        hostname = self.get_host_name()
+
+        v1_data = {
+            "instance_id": instance_id,
+            "local_hostname": hostname,
+            "public_ssh_keys": self.get_public_keys()
+        }
+
+        # Copy the v1 data to the ds.meta_data and add more fields
+        ds_meta_data = copy.deepcopy(v1_data)
+        ds_meta_data.update({
+            "hostname": hostname
+        })
+
+        return {
+            "v1": v1_data,
+            "ds": {
+                "meta_data": ds_meta_data,
+            }
+        }
+
 
 class BaseHTTPMetadataService(BaseMetadataService):
 
-    """Contract class for metadata services that are ussing HTTP(S)."""
+    """Contract class for metadata services that are using HTTP(S)."""
 
     def __init__(self, base_url, https_allow_insecure=False,
                  https_ca_bundle=None):
@@ -246,23 +301,26 @@ class BaseHTTPMetadataService(BaseMetadataService):
         else:
             return self._https_allow_insecure
 
-    def _http_request(self, url, data=None, headers=None):
+    def _http_request(self, url, data=None, headers=None, method=None):
         """Get content for received url."""
         if not url.startswith("http"):
             url = requests.compat.urljoin(self._base_url, url)
-        request_action = requests.get if not data else requests.post
-        if not data:
-            LOG.debug('Getting metadata from: %s', url)
-        else:
-            LOG.debug('Posting data to %s', url)
+        if not method:
+            if data:
+                method = "POST"
+            else:
+                method = "GET"
+        method = method.upper()
 
-        response = request_action(url=url, data=data, headers=headers,
-                                  verify=self._verify_https_request())
+        LOG.debug('Executing http request %s at %s', method, url)
+        response = requests.request(method=method, url=url, data=data,
+                                    headers=headers,
+                                    verify=self._verify_https_request())
         response.raise_for_status()
         return response.content
 
     def _get_data(self, path):
-        """Getting the required information ussing metadata service."""
+        """Getting the required information using metadata service."""
         try:
             response = self._http_request(path)
         except requests.HTTPError as exc:
@@ -274,5 +332,37 @@ class BaseHTTPMetadataService(BaseMetadataService):
             LOG.exception(exc)
             raise exception.CertificateVerifyFailed(
                 "HTTPS certificate validation failed.")
+        except (requests.ConnectionError, requests.Timeout) as exc:
+            LOG.exception(exc)
+            raise
 
         return response
+
+
+class EmptyMetadataService(BaseMetadataService):
+
+    """Empty metadata service implementation.
+
+    The empty metadata service can be used to run plugins that do not
+    rely on metadata service information, like setting ntp, mtu, etc.
+    It can be used also as a fallback metadata service, in case no other
+    previous metadata service could be loaded.
+    """
+
+    def __init__(self):
+        super(EmptyMetadataService, self).__init__()
+
+    def _get_data(self, path):
+        pass
+
+    def load(self):
+        return True
+
+    def get_admin_username(self):
+        raise NotExistingMetadataException()
+
+    def get_admin_password(self):
+        raise NotExistingMetadataException()
+
+    def is_password_changed(self):
+        raise NotExistingMetadataException()
