@@ -50,8 +50,7 @@ class BaseCreateUserPlugin(base.BasePlugin):
     def _get_password(osutils):
         # Generate a temporary random password to be replaced
         # by SetUserPasswordPlugin (starting from Grizzly)
-        maximum_length = osutils.get_maximum_password_length()
-        return osutils.generate_random_password(maximum_length)
+        return osutils.generate_random_password(CONF.user_password_length)
 
     def execute(self, service, shared_data):
         user_name = service.get_admin_username() or CONF.username
