@@ -54,6 +54,45 @@ class TestBase(unittest.TestCase):
     def test_is_password_changed(self):
         self.assertFalse(self._service.is_password_changed())
 
+    @mock.patch('cloudbaseinit.metadata.services.base.'
+                'BaseMetadataService.get_public_keys')
+    def test_get_user_pwd_encryption_key(self, mock_get_public_keys):
+        mock_get_public_keys.return_value = ['fake', 'keys']
+        result = self._service.get_user_pwd_encryption_key()
+        self.assertEqual(result, mock_get_public_keys.return_value[0])
+
+    @mock.patch('cloudbaseinit.metadata.services.base.'
+                'BaseMetadataService.get_public_keys')
+    @mock.patch('cloudbaseinit.metadata.services.base.'
+                'BaseMetadataService.get_host_name')
+    @mock.patch('cloudbaseinit.metadata.services.base.'
+                'BaseMetadataService.get_instance_id')
+    def test_get_instance_data(self, mock_instance_id, mock_hostname,
+                               mock_public_keys):
+        fake_instance_id = 'id'
+        mock_instance_id.return_value = fake_instance_id
+        fake_hostname = 'host'
+        mock_hostname.return_value = fake_hostname
+        fake_keys = ['ssh1', 'ssh2']
+        mock_public_keys.return_value = fake_keys
+
+        expected_response = {
+            'v1': {
+                "instance_id": fake_instance_id,
+                "local_hostname": fake_hostname,
+                "public_ssh_keys": fake_keys
+            },
+            'ds': {
+                'meta_data': {
+                    "instance_id": fake_instance_id,
+                    "local_hostname": fake_hostname,
+                    "public_ssh_keys": fake_keys,
+                    "hostname": fake_hostname
+                },
+            }
+        }
+        self.assertEqual(expected_response, self._service.get_instance_data())
+
 
 class TestBaseHTTPMetadataService(unittest.TestCase):
 
@@ -80,12 +119,12 @@ class TestBaseHTTPMetadataService(unittest.TestCase):
     def test_verify_https_request_with_ca_bundle(self):
         self._test_verify_https_request(https_ca_bundle="/path/to/resource")
 
-    @mock.patch('requests.post')
-    @mock.patch('requests.get')
+    @mock.patch('requests.request')
     @mock.patch("cloudbaseinit.metadata.services.base.BaseHTTPMetadataService."
                 "_verify_https_request")
-    def _test_http_request(self, mock_verify, mock_get, mock_post,
-                           mock_url, mock_data=None, mock_headers=None):
+    def _test_http_request(self, mock_verify, mock_request, mock_url,
+                           mock_data=None, mock_headers=None, mock_method=None,
+                           expected_method='GET'):
         if not mock_url.startswith('http'):
             mock_url = requests.compat.urljoin(self._mock_base_url, mock_url)
 
@@ -93,24 +132,17 @@ class TestBaseHTTPMetadataService(unittest.TestCase):
         mock_response_status = mock.Mock()
         mock_response.raise_for_status = mock_response_status
         mock_response.content = mock.sentinel.content
+        mock_request.return_value = mock_response
 
-        mock_get.return_value = mock_response
-        mock_post.return_value = mock_response
         mock_verify.return_value = mock.sentinel.verify
 
         response = self._service._http_request(url=mock_url, data=mock_data,
-                                               headers=mock_headers)
+                                               headers=mock_headers,
+                                               method=mock_method)
 
-        if mock_data:
-            mock_post.assert_called_once_with(
-                url=mock_url, data=mock_data, headers=mock_headers,
-                verify=mock.sentinel.verify
-            )
-        else:
-            mock_get.assert_called_once_with(
-                url=mock_url, data=mock_data, headers=mock_headers,
-                verify=mock.sentinel.verify
-            )
+        mock_request.assert_called_once_with(
+            method=expected_method, url=mock_url, data=mock_data,
+            headers=mock_headers, verify=mock.sentinel.verify)
 
         mock_response_status.assert_called_once_with()
         self.assertEqual(response, mock.sentinel.content)
@@ -118,12 +150,28 @@ class TestBaseHTTPMetadataService(unittest.TestCase):
     def test_http_get_request(self):
         self._test_http_request(mock_url="/path/to/resource",
                                 mock_data=None,
-                                mock_headers={})
+                                mock_headers={}, expected_method="GET")
 
     def test_http_post_request(self):
         self._test_http_request(mock_url="/path/to/resource",
                                 mock_data={"X-Cloudbase-Init", True},
-                                mock_headers={})
+                                mock_headers={}, expected_method="POST")
+
+    def test_http_force_post_request(self):
+        self._test_http_request(mock_url="/path/to/resource",
+                                mock_data=None, mock_headers={},
+                                mock_method="post", expected_method="POST")
+
+    def test_http_force_get_request(self):
+        self._test_http_request(mock_url="/path/to/resource",
+                                mock_data={"X-Cloudbase-Init", True},
+                                mock_headers={}, mock_method="get",
+                                expected_method="GET")
+
+    def test_http_force_head_request(self):
+        self._test_http_request(mock_url="/path/to/resource",
+                                mock_headers={}, mock_method="head",
+                                expected_method="HEAD")
 
     @mock.patch('requests.compat.urljoin')
     @mock.patch("cloudbaseinit.metadata.services.base."
@@ -167,3 +215,27 @@ class TestBaseHTTPMetadataService(unittest.TestCase):
         ssl_error = requests.exceptions.SSLError()
         self._test_get_data(expected_response=ssl_error,
                             expected_value=exception.CertificateVerifyFailed)
+
+
+class TestEmptyMetadataService(unittest.TestCase):
+
+    def setUp(self):
+        self._service = base.EmptyMetadataService()
+
+    def test_get_name(self):
+        self.assertEqual(self._service.get_name(), 'EmptyMetadataService')
+
+    def test__get_data(self):
+        self.assertFalse(self._service._get_data('fake_path'))
+
+    def test_get_admin_username(self):
+        self.assertRaises(base.NotExistingMetadataException,
+                          self._service.get_admin_username)
+
+    def test_get_admin_password(self):
+        self.assertRaises(base.NotExistingMetadataException,
+                          self._service.get_admin_password)
+
+    def test_is_password_changed(self):
+        self.assertRaises(base.NotExistingMetadataException,
+                          self._service.is_password_changed)
