@@ -145,6 +145,8 @@ class TestOpenNebulaService(_TestOpenNebulaService):
             d: e
             '
             ivar=10
+            TESTEMPTY=''
+            TESTEMPTY2=""
         """)
         if comment:
             content += "# A simple comment\n"
@@ -152,6 +154,8 @@ class TestOpenNebulaService(_TestOpenNebulaService):
             content = content.replace("\n", "\r\n")
         pairs = self._service._parse_shell_variables(content.encode())
         _pairs = {
+            "TESTEMPTY": b"",
+            "TESTEMPTY2": b"",
             "VAR1": b"1",
             "var2": b"abcdef",
             "VAR_VAR3": b"aaa.bbb.123.ccc",
